==> 1.4.0.tar.gz: lxqt-admin-1.4.0/lxqt-admin-user/translations/lxqt-admin-user_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Definições do grupo</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome do grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>ID do grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utilizadores pertencentes a este grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>O nome do grupo não pode estar vazio.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Definições de grupos e de utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Nome de acesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>ID do utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Diretório pessoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostrar utilizadores do sistema (apenas para utilizadores avançados)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>ID do grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Membros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Editar propriedades do item selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Adicionar novos utilizadores ou grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Apagar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Apagar o item selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Recarregar as listas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change Password</source>
        <translation>Alterar palavra-passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Alterar palavra-passe para o utilizador ou grupo selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tem a certeza de que deseja apagar o utilizador selecionado?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tem a certeza de que deseja apagar o grupo selecionado?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>Introduza a nova palavra-passe para %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Tem a certeza de que deseja definir uma palavra-passe vazia?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Definições do utilizador</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Nome de acesso:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID do utilizador:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Grupo principal:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupos</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>O utilizador pertence a estes grupos:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Console de acesso:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Diretório pessoal:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>O nome do utilizador não pode estar vazio.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation>lxqt-admin-user</translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Ação (%1) falhou:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>

==> 2.2.0.tar.gz: lxqt-admin-2.2.0/lxqt-admin-user/translations/lxqt-admin-user_pt.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Definições do grupo</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Nome do grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>ID do grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>Utilizadores pertencentes a este grupo:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>O nome do grupo não pode estar vazio.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Definições de grupos e de utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Utilizadores</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Nome de acesso</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>ID do utilizador</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Nome completo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Diretório pessoal</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Mostrar utilizadores do sistema (apenas para utilizadores avançados)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Nome</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>ID do grupo</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Membros</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="188"/>
        <source>Edit properties of the selected item</source>
        <translation>Editar propriedades do item selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="164"/>
        <source>Add new users or groups</source>
        <translation>Adicionar novos utilizadores ou grupos</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="176"/>
        <source>Delete selected item</source>
        <translation>Eliminar o item selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Properties</source>
        <translation>Propriedades</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh</source>
        <translation>Recarregar</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="200"/>
        <source>Refresh the lists</source>
        <translation>Recarregar as listas</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <location filename="../mainwindow.cpp" line="201"/>
        <source>Change Password</source>
        <translation>Alterar palavra-passe</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="212"/>
        <source>Change password for the selected user or group</source>
        <translation>Alterar palavra-passe para o utilizador ou grupo selecionado</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <location filename="../mainwindow.cpp" line="191"/>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Confirm</source>
        <translation>Confirmação</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="179"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Tem a certeza de que deseja eliminar o utilizador selecionado?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="191"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Tem a certeza de que deseja eliminar o grupo selecionado?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="203"/>
        <source>Input the new password for %1:</source>
        <translation>Introduza a nova palavra-passe para %1:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="213"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Tem a certeza de que deseja definir uma palavra-passe vazia?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Definições do utilizador</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Nome completo:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Nome de acesso:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>ID do utilizador:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Grupo principal:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Grupos</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>O utilizador pertence a estes grupos:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Avançado</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Console de acesso:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Diretório pessoal:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Erro</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>O nome do utilizador não pode estar vazio.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="229"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;Ação (%1) falhou:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
